##!/usr/bin/env python
# coding=utf-8

'''
*Copyright 2018  Ridolfa.eu*

    *
    * Licensed under the EUPL, Version 1.1 or – as soon they    *
      will be approved by the European Commission - subsequent
      versions of the EUPL (the "Licence");
    * You may not use this work except in compliance with the
      Licence.
    * You may obtain a copy of the Licence at:
    *
    * https://joinup.ec.europa.eu/software/page/eupl
    *
    * Unless required by applicable law or agreed to in
      writing, software distributed under the Licence is
      distributed on an "AS IS" basis,
    * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
      express or implied.
    * See the Licence for the specific language governing
      permissions and limitations under the Licence.
'''

import time
import DS2482rsf as dsr


def connect_pigpio(ip):
    """
    ip
        "localhost"
            if you run the program on a RasPi
        RasPi ip  (e.g. 192.148.179.65)
            if you run the program on a remote PC
    """
    try:
        import pigpio
        pi = pigpio.pi(ip)
        return (pi, pigpio)
    except:
        print("====== Can't connect to the pigpiod daemon. Library may not bei installed\n")
        return (None,None)


print("\n===============================================================")
print("---  Class  < DS2482rsf >     Examples")
print("===============================================================")


if input("\nUse config file? [y,(n)] ") == "y":
    import lib_rsf as rsf
    configfile = 'heating.yml'
    print("Config file:  ", configfile)
    cfgyaml = rsf.readconfig(configfile)
    pi, pigpiod = rsf.pigpio_connect(cfgyaml)
    I2C_address = cfgyaml["owdevices"]["I2C_bus"]["I2C_address"]
    DS2482_address = cfgyaml["owdevices"]["I2C_bus"]["DS2482_adress"]
    OW_pullup = cfgyaml["owdevices"]["I2C_bus"]["OW_pullup"]
else:
    ip = "localhost"
    #ip = "192.168.178.15"
    pi, pigpio = connect_pigpio(ip)
    # disable reading the setup file and set the parameter manually
    I2C_address = 0x1  # cfgyaml["owdevices"]["I2C_bus"]["I2C_address"]
    DS2482_address = 0x18  # cfgyaml["owdevices"]["I2C_bus"]["DS2482_adress"]
    OW_pullup = 0xE1  # cfgyaml["owdevices"]["I2C_bus"]["OW_pullup"]


classDS = dsr.app_init(pi, dsr, I2C_address, DS2482_address, OW_pullup)
classDS.DS_setchannel(0)            # DS2482-800 1-wire channel

# 1-wire Device rom id
# Hex numbers, detected by OW_singledev_info(), without leading 0x

# breadboard 1-wire devices
ow_deviceslistx = (
    ("12806dc300000027", "DS2406"),     # 10    DS2406      Switch
    ("12e9eda0000000a1", "DS2406"),     # 11    DS2406      Switch
    ("288f75420a0000e2", "DS18B20"),    # 12    DS18B20     Temperature"
    ("01f120941a00004f", "DS24SN")      # 08    DS2401      Silicon Number
    )

# heating 1-wire devices
ow_deviceslist = (
    ("28a9312c09000071", "DS18B20"),    # 01    [dev rom, device type]
    ("28a3f12a09000095", "DS18B20"),    # 02    DS18B20     Temperature
    ("2841d629090000f3", "DS18B20"),    # 03    DS18B20     Temperature
    ("013b40731a0000c1", "DS24SN")      # 05    DS2401      Silicon Number
    )

# convert device id string to a device byte list
ow_devices = []
for z in ow_deviceslist:
    x = z[0]        # device rom
    singledev = []
    for i in range(0, len(x), 2):
        byte = int(x[i]+x[i+1], 16)
        singledev.append(byte)
    ow_devices.append([singledev, z[1]])

if input("\nExecute a single device test? [y,(n)] ") == "y":
    print("\n### Singel Device Test ----------------------------------")
    print("--- Connect only one device to the 1-wire bus")
    print("--- More than one device causes errors\n")

    if classDS.OW_singledev_info() != 1:
        print("OW_singledev_info():\tfailed")
else:
    print("\n### Scan all pre-defined device -------------------------")
    for i in ow_devices:
        devrom = i[0]
        devtype = i[1]
        print("\n", devtype)
        print(hex(devrom[0]), "\t", [hex(x) for x in devrom])

        if devtype == "DS2406":
            on = True
            for j in range(0, 5):
                onoff = "w1"
                on = not on
                if on: onoff = "w0"
                devdata = classDS.ds2406(devrom, ds2406_mode=onoff, ds2406_pio="A")
                time.sleep(0.5)
                # print("Device data2406\t{}  {}  {}".format(devdata[0], devdata[1], devdata[2]))
        elif devtype == "DS18B20":
            devdata = classDS.ds18b20(devrom)
        elif devtype == "DS24SN":
            devdata = classDS.ds24sn(devrom)
        else:
            print("Unknown device")
        print("Device data:\t{}  {}  {}".format(devdata[0], devdata[1], devdata[2]))
        time.sleep(2)

dsr.app_close(classDS)
pi.stop()
